/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.farm;

import java.awt.Color;
import javax.swing.JCheckBox;
import javax.swing.JPanel;
import net.miginfocom.swing.MigLayout;
import nl.cloudfarming.client.farm.model.Farm;
import nl.cloudfarming.client.farm.type.FarmDetailsPanel;
import org.openide.WizardDescriptor;
import org.openide.util.NbBundle;
import org.openide.util.NbBundle.Messages;

/**
 *
 * @author Timon Veenstra
 */
@Messages({
    "farm.wizard.checkbox.create_fieldplan=Create a fieldplan for this Farm after wizard finishes."
})
public class FarmWizardDetailsVisual extends JPanel {

    private final FarmWizardDetailsPanel panel;
    private final Farm farm = new Farm();
    private final FarmDetailsPanel farmDetailsPanel;
    private final JCheckBox createFieldplanCheckBox = new JCheckBox();
    public final static String PROP_CREATE_FIELPLAN = "PROP_CREATE_FIELPLAN";
    
    /**
     * Creates new form FarmWizardDetailsVisual
     */
    FarmWizardDetailsVisual(FarmWizardDetailsPanel panel) {
        farmDetailsPanel = new FarmDetailsPanel(farm);
        this.panel = panel;
        this.setBackground(Color.white);
        createFieldplanCheckBox.setText(NbBundle.getMessage(FarmWizardDetailsVisual.class, "farm.wizard.checkbox.create_fieldplan"));
        createFieldplanCheckBox.setBackground(Color.white);
        // Determine height
        int height = farmDetailsPanel.getHeight() + 30;
        
        this.setPreferredSize(new java.awt.Dimension(600, height));
        this.setLayout(new MigLayout("wrap 1, insets 0 0 0 0"));
        
        this.add(farmDetailsPanel);
        this.add(createFieldplanCheckBox);
    }


    boolean valid(WizardDescriptor wizardDescriptor) {
        return true;
    }

    void read(WizardDescriptor wizardDescriptor) {
        String projectName = (String) wizardDescriptor.getProperty(FarmWizardIterator.PROP_PROJECT_NAME);
        if (projectName == null) {
            projectName = Bundle.Farm_default_name();
        }
        farm.setName(projectName);
        
        String registrationNumber = (String) wizardDescriptor.getProperty(Farm.PROP_REGISTRATIONNUMBER);
        farm.setRegistrationNumber(registrationNumber);        
    }

    void store(WizardDescriptor wizardDescriptor) {
        wizardDescriptor.putProperty(Farm.PROP_REGISTRATIONNUMBER, farm.getRegistrationNumber());
        wizardDescriptor.putProperty(FarmWizardIterator.PROP_PROJECT_NAME, farm.getName());
        wizardDescriptor.putProperty(FarmWizardDetailsVisual.PROP_CREATE_FIELPLAN, createFieldplanCheckBox.isSelected());
    }

    void validate(WizardDescriptor wizardDescriptor) {
        //TODO implement
    }
}
